Font

Struct Font 

pub struct Font {
    pub tables: BTreeMap<Tag, Table>,
    /* private fields */
}
An OpenType font object

Fields

tables: BTreeMap<Tag, Table>

Dictionary of tables in the font

Implementations

Source

impl Font

pub fn new(sfnt_version: SfntVersion) -> Self

Create a new font, empty of a given version (TrueType/OpenType)

pub fn get_table<'a>( &'a mut self, tag: &Tag, ) -> Result<Option<&'a mut Table>, DeserializationError>

Retrieve a table from the font

If the table tag is known to this library and can be deserialized, this is done and the appropriate Table enum entry is returned. If not, then a Table::Unknown is returned with the binary table data as a Vec.

Returns an Err if the table could not be correctly deserialized. Returns Ok(None) if the table was not present within the font. Returns Ok(Some(Table)) if the table was present.

pub fn fully_deserialize(&mut self)

Deserializes all tables in the font.

This is done in the correct order (as some tables can only be deserialized after certain others have been processed), so is a helpful way of getting the font into a useful state before working on it.

pub fn save<T>(&mut self, file: &mut T)
where T: Write,

Writes the font to the given file handle

pub fn num_glyphs(&mut self) -> u16

Total number of glyphs in the font, from the maxp table.

Deserializes the maxp table if this is not already done.

pub fn compile_glyf_loca_maxp(&mut self)

Compiles all dependent tables to binary.

Certain tables cannot be serialized independently, but need data from other tables to be passed in to the deserializer. We handle this by manually compiling those tables to binary here and replacing them with Table::Unknown. This is automatically called on .save.